==> Repetier-Server-Frontend-0.86.2.zip: Repetier-Server-Frontend/wwwsrc/modules/front2/app/app.module.ts <==
/* (C) 2016 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {NgModule}      from '@angular/core';
import {BrowserModule} from '@angular/platform-browser';
import {RepetierServer, RSQRCode, VisualAids} from '@repetier/binding';
import {FrontUIModule,RSUIVisualAids} from '@repetier/front-ui';
import {routing, appRoutingProviders} from "./app.routes";
import {HttpModule} from '@angular/http';
import {AppComponent}  from './app.component';
import {PrinterListComponent} from "./printers.component";
import {DashboardComponent} from "./dashboard.component";
import {PrintStatusComponent} from "./printstatus.component";
import {
    MoveComponent,
    MoveZComponent,
    MoveEComponent
} from "./move.component";
import {NetworksComponent} from "./networks.component";
import {GCodesComponent, GCodeInfo} from "./gcodes.component";
import {PrintQueueComponent} from "./printqueue.component";
import {ServerCommandsComponent} from "./server-commands.component";
import {PrinterCommandsComponent} from "./printer-commands.component";
import {WebcamComponent} from "./webcam.component";
import {ParamsComponent} from "./params.component";
import {ImportComponent} from "./import.component";
import {WLANComponent} from "./wlan.component";
import {TemperaturesComponent} from "./temperatures.component";
import {LanguagesComponent} from "./languages.component";
import {MessagesComponent} from "./messages.component";
import {ChangeFilamentComponent} from "./changefilament.component";
import {ConsoleComponent} from "./console.component";
import {ScreensaverComponent} from "./screensaver.component";

@NgModule({
    imports: [
        BrowserModule,
        HttpModule,
        routing,
        FrontUIModule
    ],
    declarations: [
        AppComponent,
        DashboardComponent,
        PrinterListComponent,
        PrintStatusComponent,
        MoveComponent,
        MoveZComponent,
        MoveEComponent,
        NetworksComponent,
        GCodesComponent,
        PrintQueueComponent,
        ServerCommandsComponent,
        PrinterCommandsComponent,
        WebcamComponent,
        ParamsComponent,
        ImportComponent,
        WLANComponent,
        TemperaturesComponent,
        LanguagesComponent,
        MessagesComponent,
        ChangeFilamentComponent,
        ConsoleComponent,
        GCodeInfo,
        ScreensaverComponent
    ],
    bootstrap: [AppComponent],
    providers: [
        RepetierServer,
        appRoutingProviders,
        { provide: VisualAids, useClass: RSUIVisualAids }
    ]
})
export class AppModule {
}

==> Repetier-Server-Frontend-0.90.1.zip: Repetier-Server-Frontend/wwwsrc/modules/front2/app/app.module.ts <==
/* (C) 2016 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {NgModule}      from '@angular/core';
import {BrowserModule} from '@angular/platform-browser';
import {RepetierServer, RSQRCode, VisualAids} from '@repetier/binding';
import {FrontUIModule,RSUIVisualAids} from '@repetier/front-ui';
import {routing, appRoutingProviders} from "./app.routes";
import {HttpModule} from '@angular/http';
import {AppComponent}  from './app.component';
import {PrinterListComponent} from "./printers.component";
import {DashboardComponent} from "./dashboard.component";
import {PrintStatusComponent} from "./printstatus.component";
import {
    MoveComponent,
    MoveZComponent,
    MoveEComponent
} from "./move.component";
import {NetworksComponent} from "./networks.component";
import {GCodesComponent, GCodeInfo} from "./gcodes.component";
import {PrintQueueComponent} from "./printqueue.component";
import {ServerCommandsComponent} from "./server-commands.component";
import {PrinterCommandsComponent} from "./printer-commands.component";
import {WebcamComponent} from "./webcam.component";
import {ParamsComponent} from "./params.component";
import {ImportComponent} from "./import.component";
import {WLANComponent} from "./wlan.component";
import {TemperaturesComponent} from "./temperatures.component";
import {LanguagesComponent} from "./languages.component";
import {MessagesComponent} from "./messages.component";
import {ChangeFilamentComponent} from "./changefilament.component";
import {ConsoleComponent} from "./console.component";
import {ScreensaverComponent} from "./screensaver.component";
import {UnlockScreenComponent} from "./unlock.component";

@NgModule({
    imports: [
        BrowserModule,
        HttpModule,
        routing,
        FrontUIModule
    ],
    declarations: [
        AppComponent,
        DashboardComponent,
        PrinterListComponent,
        PrintStatusComponent,
        MoveComponent,
        MoveZComponent,
        MoveEComponent,
        NetworksComponent,
        GCodesComponent,
        PrintQueueComponent,
        ServerCommandsComponent,
        PrinterCommandsComponent,
        WebcamComponent,
        ParamsComponent,
        ImportComponent,
        WLANComponent,
        TemperaturesComponent,
        LanguagesComponent,
        MessagesComponent,
        ChangeFilamentComponent,
        ConsoleComponent,
        GCodeInfo,
        ScreensaverComponent,
        UnlockScreenComponent
    ],
    bootstrap: [AppComponent],
    providers: [
        RepetierServer,
        appRoutingProviders,
        { provide: VisualAids, useClass: RSUIVisualAids }
    ]
})
export class AppModule {
}
